@@ -28,9 +28,10 @@ $info{forward}{proc}{impl} = sub {
 
 $info{group}{proc}{impl} = sub {
   my ($data) = @_;
+  return if exists $data->{'no impl'};
   create_cc_file (type => 'impl',
 		  cxx => true,
-		  namespace => 'acommon',
+		  namespace => 'aspell',
 		  dir => "lib",
 		  pre_ext => "-c",
 		  header => false,
@@ -45,13 +46,20 @@ $info{class}{proc}{impl} = sub {
   foreach (grep {$_ ne ''} split /\s*,\s*/, $data->{'c impl headers'}) {
     $accum->{headers}{$_} = true;
   }
-  foreach my $d (@{$data->{data}}) {
+  if (exists $data->{'indirect'}) {
+    $accum->{headers}{(to_lower $data->{name}).'-c'} = true;
+  }
+  my @d = @{$data->{data}};
+  my $d;
+  while (($d = shift @d)) {
     next unless one_of $d->{type}, qw(method constructor destructor);
+    next if exists $d->{'no c impl'};
     my @parms = @{$d->{data}} if exists $d->{data};
     my $m = make_c_method $data->{name}, $d, {mode=>'cc_cxx', use_name=>true}, %$accum;
     next unless defined $m;
     $ret .= "extern \"C\" $m\n";
     $ret .= "{\n";
+    my $obj = exists $data->{'indirect'} ? "ths->real->" : "ths->";
     if (exists $d->{'c impl'}) {
       $ret .= cmap {"  $_\n"} split /\n/, $d->{'c impl'};
     } else {
@@ -74,7 +82,7 @@ $info{class}{proc}{impl} = sub {
 	  }
 	}
 	my $parms = '('.(join ', ', @parms).')';
-	my $exp = "ths->".to_lower($d->{name})."$parms";
+	my $exp = $obj.to_lower($d->{name})."$parms";
 	if (exists $d->{'posib err'}) {
 	  $accum->{headers}{'posib err'} = true;
 	  $ret .= "  PosibErr<$ret_native> ret = $exp;\n";
@@ -91,27 +99,54 @@ $info{class}{proc}{impl} = sub {
 	  $ret .= "  ths->temp_str = $exp;\n";
 	  $exp = "ths->temp_str.c_str()";
 	} elsif ($ret_type->{type} eq 'encoded string') {
-	  die; 
-	  # This is not used and also not implemented right
-	  $ret .= "  if (to_encoded_ != 0) (*to_encoded)($exp,temp_str_);\n";
-	  $ret .= "  else                  temp_str_ = $exp;\n";
-	  $exp = "temp_str_0.data()";
+          $ret .= "  const char * s = $exp;\n";
+          $ret .= "  if (s && ths->from_internal_) {\n";
+          $ret .= "    ths->temp_str_$snum.clear();\n";
+          $ret .= "    ths->from_internal_->convert(s,-1,ths->temp_str_$snum);\n";
+          $ret .= "    ths->from_internal_->append_null(ths->temp_str_$snum);\n";
+          $ret .= "    s = ths->temp_str_$snum.data();\n";
+          $ret .= "  }\n";
+          $exp = "s";
+          $snum++;
 	}
 	if ($ret_type->{type} eq 'const word list') {
 	  $accum->{headers}{'word list'} = true;
-	  $ret .= "  const_cast<WordList *>(ret.data)->from_internal_ = ths->from_internal_;\n";
+          $ret .= "  if (ret.data)\n";
+	  $ret .= "    const_cast<WordList *>(ret.data)->from_internal_ = ths->from_internal_;\n";
 	}
 	$ret .= "  ";
 	$ret .= "return " unless $ret_type->{type} eq 'void';
 	$ret .= $exp;
 	$ret .= ";\n";
       } elsif ($d->{type} eq 'constructor') {
+        $accum->{headers}{error} = true;
 	my $name = $d->{name} ? $d->{name} : "new $data->{name}";
 	$name =~ s/aspell\ ?//; # FIXME: Abstract this in a function
 	$name = to_lower($name);
-	shift @parms if exists $d->{'returns alt type'}; # FIXME: Abstract this in a function
-	my $parms = '('.(join ', ', map {$_->{name}} @parms).')';
-	$ret .= "  return $name$parms;\n";
+        shift @parms if exists $d->{'returns alt type'}; # FIXME: Abstract this in a function
+        my $parms = '('.(join ', ', map {$_->{name}} @parms).')';
+        my $class = to_mixed($data->{name});
+        if (exists $d->{'posib err'}) {
+	  $accum->{headers}{'error'} = true;
+	  $accum->{headers}{'posib err'} = true;
+          my $c = exists $data->{'base'} ? $data->{'base'} : $class;
+          $ret .= "  PosibErr<$c *> ret = $name$parms;\n";
+          $ret .= "  if (ret.has_err()) {\n";
+          $ret .= "    return new CanHaveError(ret.release_err());\n";
+          $ret .= "  } else {\n";
+          if (exists $data->{'indirect'}) {
+            $ret .= "    return new $class(ret);\n";
+          } else {
+            $ret .= "    return ret;\n";
+          }
+          $ret .= "  }\n";
+        } elsif (exists $d->{'conversion'}) {
+          $ret .= "  return static_cast<$class *>(obj);\n";
+        } elsif (exists $data->{'indirect'}) {
+	  $ret .= "  return new $class($name$parms);\n";
+        } else {
+	  $ret .= "  return $name$parms;\n";
+        }
       } elsif ($d->{type} eq 'destructor') {
 	$ret .= "  delete ths;\n";
       }
