@@ -70,17 +70,6 @@ namespace aspell {
     ungetc(c, file_);
     return *this;
   }
-  FStream & FStream::operator<< (const char * str)
-  {
-    fputs(str, file_);
-    return *this;
-  }
-
-  FStream & FStream::operator<< (const String &str)
-  {
-    fputs(str.c_str(), file_);
-    return *this;
-  }
 
   FStream & FStream::operator<< (ParmStr str)
   {
