@@ -11,7 +11,7 @@
 
 #include "parm_string.hpp"
 
-namespace acommon {
+namespace aspell {
 
   // FIXME: Add Print Method compatible with printf and friends.
   //   Than avoid code bloat by using it in many places instead of
@@ -25,7 +25,9 @@ namespace acommon {
 
     virtual int vprintf(const char *format, va_list ap) = 0;
 
+#ifdef __GNUC__
     __attribute__ ((format (printf,2,3)))
+#endif
       int printf(const char * format, ...)
     {
       va_list ap;
