@@ -17,14 +17,11 @@
 
 namespace aspell {
 
-  // These template instantiations are needed for darwin but VC6 has
-  // problems with them
-#ifndef _MSC_VER
+  // needed for darwin
   template HashTable<StringMap::Parms>::iterator 
            HashTable<StringMap::Parms>::find_i(char const* const&, bool&);
   template std::pair<HashTable<StringMap::Parms>::iterator,bool>
            HashTable<StringMap::Parms>::insert(const StringPair &);
-#endif
   template void HashTable<StringMap::Parms>::init(unsigned int);
   template void HashTable<StringMap::Parms>::del(void);
   template HashTable<StringMap::Parms>::size_type
