@@ -15,7 +15,7 @@
 #include "objstack.hpp"
 
 
-namespace acommon {
+namespace aspell {
 
 class StringPairEnumeration;
 
@@ -28,7 +28,7 @@ public: // but don't use
     typedef const char * Key;
     const char * key(const Value & v) {return v.first;}
     static const bool is_multi = false;
-    acommon::hash<const char *>  hash;
+    aspell::hash<const char *>  hash;
     bool equal(const char * x, const char * y) {return strcmp(x,y) == 0;}
   };
   typedef StringPair Value_;
@@ -38,7 +38,6 @@ public: // but don't use
 private:
   HashTable<Parms> lookup_;
   ObjStack buffer_;
-  const char empty_str[1];
 
   void copy(const StringMap & other);
   
@@ -46,8 +45,8 @@ private:
 public:
   PosibErr<void> clear() {lookup_.clear(); buffer_.reset(); return no_err;}
   
-  StringMap() : empty_str() {}
-  StringMap(const StringMap & other) : empty_str() {copy(other);}
+  StringMap() {}    
+  StringMap(const StringMap & other) {copy(other);}
   StringMap & operator= (const StringMap & o) {clear(); copy(o); return *this;}
   ~StringMap() {}
   
@@ -62,7 +61,7 @@ public:
   
   // insert a new element.   Will NOT overwrite an existing entry.
   // returns false if the element already exists.
-  bool insert(ParmString key, ParmString value) {
+  bool insert(ParmStr key, ParmStr value) {
     pair<Iter_,bool> res = lookup_.insert(Value_(key,0));
     if (res.second) {
       res.first->first  = buffer_.dup(key);
@@ -72,11 +71,11 @@ public:
       return false;
     }
   }
-  PosibErr<bool> add(ParmString key) {
+  PosibErr<bool> add(ParmStr key) {
     pair<Iter_,bool> res = lookup_.insert(Value_(key,0));
     if (res.second) {
       res.first->first  = buffer_.dup(key);
-      res.first->second = empty_str;
+      res.first->second = "";
       return true;
     } else {
       return false;
@@ -84,7 +83,7 @@ public:
   }
   // insert a new element. WILL overwrite an exitsing entry
   // always returns true
-  bool replace(ParmString key, ParmString value) {
+  bool replace(ParmStr key, ParmStr value) {
     pair<Iter_,bool> res = lookup_.insert(Value_(key,0));
     if (res.second) {
       res.first->first  = buffer_.dup(key);
@@ -96,12 +95,12 @@ public:
   }
   
   // removes an element.  Returns true if the element existed.
-  PosibErr<bool> remove(ParmString key) {return lookup_.erase(key);}
+  PosibErr<bool> remove(ParmStr key) {return lookup_.erase(key);}
   
   // looks up an element.  Returns null if the element did not exist.
   // returns an empty string if the element exists but has a null value
   // otherwise returns the value
-  const char * lookup(ParmString key) const 
+  const char * lookup(ParmStr key) const 
   {
     CIter_ i = lookup_.find(key);
     if (i == lookup_.end())
@@ -110,7 +109,7 @@ public:
       return i->second;
   }  
   
-  bool have(ParmString key) const {return lookup(key) != 0;}
+  bool have(ParmStr key) const {return lookup(key) != 0;}
   
   unsigned int size() const {return lookup_.size();}
   bool empty() const {return lookup_.empty();}
