@@ -15,18 +15,6 @@ namespace aspell
   class Vector : public std::vector<T>
   {
   public:
-
-#if defined _MSC_VER && _MSC_VER < 1300
-    // Bring type definitions from the std::vector class to aspell::Vector
-    typedef T value_type;
-    typedef std::vector<T>::size_type size_type;
-    typedef std::vector<T>::difference_type difference_type;
-    typedef std::vector<T>::reference reference;
-    typedef std::vector<T>::const_reference const_reference;
-    typedef std::vector<T>::iterator iterator;
-    typedef std::vector<T>::const_iterator const_iterator;
-#endif //_MSC_VER
-
     Vector() {}
     Vector(unsigned int s) : std::vector<T>(s) {}
     Vector(unsigned int s, const T & val) : std::vector<T>(s, val) {}
@@ -35,10 +23,10 @@ namespace aspell
       this->push_back(t);
     }
     void append(const T * begin, unsigned int size) {
-      insert(this->end(), begin, begin+size);
+      this->insert(this->end(), begin, begin+size);
     }
     void append(const T * begin, const T * end) {
-      insert(this->end(), begin, end);
+      this->insert(this->end(), begin, end);
     }
     int alloc(int s) {
       int pos = this->size();
