@@ -123,7 +123,7 @@ namespace aspell {
       c->filter_mode_notifier = this;
     }
     
-    Notifier * clone(Config * c) const {return new ModeNotifierImpl(*this, c);}
+    ModeNotifierImpl * clone(Config * c) const {return new ModeNotifierImpl(*this, c);}
 
     PosibErr<void> item_updated(const KeyInfo * ki, ParmStr);
     PosibErr<void> list_updated(const KeyInfo * ki);
@@ -243,7 +243,7 @@ namespace aspell {
       for ( Vector<MagicString>::iterator it = magicKeys.begin() ;
             it != magicKeys.end() ; it++ ) {
         PosibErr<bool> magicMatch = it->matchFile(in,ext);
-        if (    magicMatch.data 
+        if (    magicMatch 
              || magicMatch.has_err() ) {
           if ( closeFile ) {
             fclose ( in );
@@ -280,10 +280,12 @@ namespace aspell {
   }
 
   void FilterMode::MagicString::remExtension(const String & ext) {
-    for ( Vector<String>::iterator it = fileExtensions.begin() ;
-          it != fileExtensions.end() ; it++ ) {
-      if ( *it == ext ) {
-        fileExtensions.erase(it);
+    Vector<String>::iterator it = fileExtensions.begin();
+    while (it != fileExtensions.end()) {
+      if (*it == ext) {
+        it = fileExtensions.erase(it);
+      } else {
+        it++;
       }
     }
   }
@@ -674,7 +676,7 @@ namespace aspell {
             if ( regend == regbegin ) 
             {
               char charCount[64];
-              sprintf(&charCount[0],"%i",regbegin - (char *)dp.value);
+              sprintf(&charCount[0],"%li",(long)(regbegin - (char *)dp.value));
               return  make_err(empty_file_ext,charCount).with_file(possModeFile,dp.line_num);
             }
 
@@ -692,7 +694,7 @@ namespace aspell {
             if ( regend == regbegin ) 
             {
               char charCount[64];
-              sprintf(&charCount[0],"%i",regbegin - (char *)dp.value);
+              sprintf(&charCount[0],"%li",(long)(regbegin - (char *)dp.value));
               return  make_err(empty_file_ext,charCount).with_file(possModeFile,dp.line_num);
             }
             swap = *regend;
@@ -707,7 +709,7 @@ namespace aspell {
             char * dest = magic.mstr();
             const char * src  = magic.mstr();
             while (*src) {
-              if (*src == '\\' && src[1] == '/' || src[1] == '#')
+              if ((*src == '\\' && src[1] == '/') || src[1] == '#')
                 ++src;
               *dest++ = *src++;
             }
@@ -727,7 +729,7 @@ namespace aspell {
           if (extCount > 0 ) continue;
 
           char charCount[64];
-          sprintf(&charCount[0],"%i",strlen((char *)dp.value));
+          sprintf(&charCount[0],"%lu",(unsigned long)strlen((char *)dp.value));
           return  make_err(empty_file_ext,charCount).with_file(possModeFile,dp.line_num);
         }
 
