@@ -1,6 +1,6 @@
 // This file is part of The New Aspell
 // Copyright (C) 2004 by Tom Snyder
-// Copyright (C) 2004-2001 by Kevin Atkinson under the GNU LGPL license
+// Copyright (C) 2001-2004 by Kevin Atkinson under the GNU LGPL license
 // version 2.0 or 2.1.  You should have received a copy of the LGPL
 // license along with this library if you did not you can find
 // it at http://www.gnu.org/.
@@ -28,8 +28,7 @@
 #include "indiv_filter.hpp"
 #include "string_map.hpp"
 #include "mutable_container.hpp"
-#include "copy_ptr-t.hpp"
-#include "clone_ptr-t.hpp"
+#include "clone_ptr.hpp"
 #include "filter_char_vector.hpp"
 
 //right now unused option
@@ -40,7 +39,7 @@
 
 namespace {
 
-  using namespace acommon;
+  using namespace aspell;
 
   class ToLowerMap : public StringMap
   {
@@ -58,7 +57,7 @@ namespace {
     }
   };
 
-  class SgmlFilter : public IndividualFilter 
+  class SgmlFilter : public NormalFilter 
   {
     // State enum. These states track where we are in the HTML/tag/element constructs.
     // This diagram shows the main states. The marked number is the state we enter
@@ -105,6 +104,7 @@ namespace {
     ScanState in_what;
 	     // which quote char is quoting this attrib value.
 	
+	
     FilterChar::Chr  quote_val;   
 	    // one char prior to this one. For escape handling and such.
     FilterChar::Chr  lookbehind;   
@@ -120,9 +120,13 @@ namespace {
     StringMap check_attribs; // list of attribs that we *should* spell check.
     StringMap skip_tags;   // list of tags that start a no-check-at-all zone.
 
+    String which;
+
     bool process_char(FilterChar::Chr c);
  
-    public:
+  public:
+
+    SgmlFilter(const char * n) : which(n) {}
 
     PosibErr<bool> setup(Config *);
     void reset();
@@ -131,12 +135,12 @@ namespace {
 
   PosibErr<bool> SgmlFilter::setup(Config * opts) 
   {
-    name_ = "sgml-filter";
-    order_num_ = 0.35;
+    set_name(which);
+    set_order_num(0.35);
     check_attribs.clear();
     skip_tags.clear();
-    opts->retrieve_list("filter-sgml-skip", &skip_tags);
-    opts->retrieve_list("filter-sgml-check", &check_attribs);
+    opts->retrieve_list("f-" + which + "-skip",  &skip_tags);
+    opts->retrieve_list("f-" + which + "-check", &check_attribs);
     reset();
     return true;
   }
@@ -407,10 +411,12 @@ namespace {
   //
   //
 
-  class SgmlDecoder : public IndividualFilter 
+  class SgmlDecoder : public ConversionFilter 
   {
     FilterCharVector buf;
+    String which;
   public:
+    SgmlDecoder(const char * n) : which(n) {}
     PosibErr<bool> setup(Config *);
     void reset() {}
     void process(FilterChar * &, FilterChar * &);
@@ -418,8 +424,8 @@ namespace {
 
   PosibErr<bool> SgmlDecoder::setup(Config *) 
   {
-    name_ = "sgml-decoder";
-    order_num_ = 0.65;
+    set_name(which, Decoder);
+    set_order_num(0.65);
     return true;
   }
 
@@ -433,21 +439,21 @@ namespace {
 	FilterChar * i0 = i;
 	FilterChar::Chr chr;
 	++i;
-	if (*i == '#') {
+	if (i != stop && *i == '#') {
 	  chr = 0;
 	  ++i;
-	  while (asc_isdigit(*i)) {
+	  while (i != stop && asc_isdigit(*i)) {
 	    chr *= 10;
 	    chr += *i - '0';
 	    ++i;
 	  }
 	} else {
-	  while (asc_isalpha(*i) || asc_isdigit(*i)) {
+	  while (i != stop && (asc_isalpha(*i) || asc_isdigit(*i))) {
 	    ++i;
 	  }
 	  chr = '?';
 	}
-	if (*i == ';')
+	if (i != stop && *i == ';')
 	  ++i;
 	buf.append(FilterChar(chr, i0, i));
       } else {
@@ -461,54 +467,76 @@ namespace {
   }
 
   //
-  //
+  // Sgml Encoder - BROKEN do not use
   //
 
-  class SgmlEncoder : public IndividualFilter 
-  {
-    FilterCharVector buf;
-  public:
-    PosibErr<bool> setup(Config *);
-    void reset() {}
-    void process(FilterChar * &, FilterChar * &);
-  };
+//   class SgmlEncoder : public IndividualFilter 
+//   {
+//     FilterCharVector buf;
+//     String which;
+//   public:
+//     SgmlEncoder(const char * n) : which(n) {}
+//     PosibErr<bool> setup(Config *);
+//     void reset() {}
+//     void process(FilterChar * &, FilterChar * &);
+//   };
 
-  PosibErr<bool> SgmlEncoder::setup(Config *) 
-  {
-    name_ = "sgml-encoder";
-    order_num_ = 0.99;
-    return true;
-  }
+//   PosibErr<bool> SgmlEncoder::setup(Config *) 
+//   {
+//     name_ = which + "-encoder";
+//     order_num_ = 0.99;
+//     return true;
+//   }
 
-  void SgmlEncoder::process(FilterChar * & start, FilterChar * & stop)
-  {
-    buf.clear();
-    FilterChar * i = start;
-    while (i != stop)
-    {
-      if (*i > 127) {
-	buf.append("&#", i->width);
-	char b[10];
-	sprintf(b, "%d", i->chr);
-	buf.append(b, 0);
-	buf.append(';', 0);
-      } else {
-	buf.append(*i);
-      }
-      ++i;
-    }
-    buf.append('\0');
-    start = buf.pbegin();
-    stop  = buf.pend() - 1;
-  }
+//   void SgmlEncoder::process(FilterChar * & start, FilterChar * & stop)
+//   {
+//     buf.clear();
+//     FilterChar * i = start;
+//     while (i != stop)
+//     {
+//       if (*i > 127) {
+// 	buf.append("&#", i->width);
+// 	char b[10];
+// 	sprintf(b, "%d", i->chr);
+// 	buf.append(b, 0);
+// 	buf.append(';', 0);
+//       } else {
+// 	buf.append(*i);
+//       }
+//       ++i;
+//     }
+//     buf.append('\0');
+//     start = buf.pbegin();
+//     stop  = buf.pend() - 1;
+//   }
 }
 
-C_EXPORT 
-IndividualFilter * new_aspell_sgml_filter() {return new SgmlFilter;}
-C_EXPORT 
-IndividualFilter * new_aspell_sgml_decoder() {return new SgmlDecoder;}
-//C_EXPORT 
-//IndividualFilter * new_aspell_sgml_encoder() {return new SgmlEncoder;}
+C_EXPORT IndividualFilter * new_aspell_sgml_filter() 
+{
+  return new SgmlFilter("sgml");
+}
+C_EXPORT IndividualFilter * new_aspell_sgml_decoder() 
+{
+  return new SgmlDecoder("sgml");
+}
+// C_EXPORT IndividualFilter * new_aspell_sgml_encoder() 
+// {
+//   return new SgmlEncoder("sgml");
+// }
+
+C_EXPORT IndividualFilter * new_aspell_html_filter() 
+{
+  return new SgmlFilter("html");
+}
+C_EXPORT IndividualFilter * new_aspell_html_decoder() 
+{
+  return new SgmlDecoder("html");
+}
+// C_EXPORT IndividualFilter * new_aspell_html_encoder() 
+// {
+//   return new SgmlEncoder("html");
+// }
+
 
 /* Example HTML:
 
