@@ -194,7 +194,7 @@ struct CondsLookupParms {
   typedef const Conds * Value;
   typedef const char * Key;
   static const bool is_multi = false;
-  hash<const char *> hfun;
+  aspell::hash<const char *> hfun;
   size_t hash(const char * s) {return hfun(s);}
   bool equal(const char * x, const char * y) {return strcmp(x,y) == 0;}
   const char * key(const Conds * c) {return c->str;}
@@ -912,7 +912,7 @@ WordAff * AffixMgr::expand(ParmString word, ParmString aff,
   WordAff * cur = head;
   cur->word = buf.dup(word);
   cur->aff  = suf;
-  for (const byte *c = (const byte *)aff.str(), *end = c + aff.size();
+  for (const byte * c = (const byte *)aff.str(), *end = c + aff.size();
        c != end; 
        ++c) 
   {
