@@ -3,20 +3,20 @@
 
 #include <vector>
 
-namespace aspeller {
+namespace aspell { namespace sp {
 
   class ShortMatrix {
     int x_size;
     int y_size;
     short * data;
   public:
+    void init(int sx, int sy, short * d) {x_size = sx; y_size = sy; data = d;}
     ShortMatrix() {}
     ShortMatrix(int sx, int sy, short * d) {init(sx,sy,d);}
-    void init(int sx, int sy, short * d) {x_size = sx; y_size = sy; data = d;}
     short operator() (int x, int y) const {return data[x + y*x_size];}
     short & operator() (int x, int y) {return data[x + y*x_size];}
   };
 
-}
+} }
 
 #endif
