@@ -35,13 +35,11 @@
 #include "errors.hpp"
 #include "fstream.hpp"
 #include "getdata.hpp"
-#include "language.hpp"
+#include "lang_impl.hpp"
 #include "objstack.hpp"
 #include "vararray.hpp"
 
-using namespace acommon;
-
-namespace aspeller {
+namespace aspell { namespace sp {
 
   const char * const PhonetParms::rules_end = "";
   
@@ -73,10 +71,18 @@ namespace aspeller {
   };
 
   static void init_phonet_hash(PhonetParms & parms);
+
+  // like strcpy but safe if the strings overlap
+  //   but only if dest < src
+  static inline void strmove(char * dest, char * src) {
+    while (*src) 
+      *dest++ = *src++;
+    *dest = '\0';
+  }
   
   PosibErr<PhonetParms *> new_phonet(const String & file, 
                                      Conv & iconv,
-                                     const Language * lang) 
+                                     const LangImpl * lang) 
   {
     String buf; DataPair dp;
 
@@ -89,6 +95,7 @@ namespace aspeller {
 
     parms->followup        = true;
     parms->collapse_result = false;
+    parms->remove_accents  = true;
 
     int num = 0;
     while (getdata_pair(in, dp, buf)) {
@@ -114,6 +121,8 @@ namespace aspeller {
 	parms->collapse_result = to_bool(dp.value);
       } else if (dp.key == "version") {
 	parms->version = dp.value;
+      } else if (dp.key == "remove_accents") {
+        parms->remove_accents = to_bool(dp.value);
       } else {
 	*r = parms->strings.dup(iconv(dp.key));
 	++r;
@@ -133,6 +142,15 @@ namespace aspeller {
     *(r+1) = PhonetParms::rules_end;
     parms->rules = (const char * *)parms->data;
 
+
+    for (unsigned i = 0; i != 256; ++i) {
+      parms->to_clean[i] = (lang->char_type(i) > LangImpl::NonLetter 
+                            ? (parms->remove_accents 
+                               ? lang->to_upper(lang->de_accent(i)) 
+                               : lang->to_upper(i))
+                            : 0);
+    }
+
     init_phonet_hash(*parms);
 
     return parms;
@@ -187,9 +205,14 @@ namespace aspeller {
 
     typedef unsigned char uchar;
     
-    /**  to_upperize string  **/
-    parms.lang->LangImpl::to_upper(word, inword);
-
+    /**  to convert string to uppercase and possible remove accents **/
+    char * res = word;
+    for (const char * str = inword; *str; ++str) {
+      char c = parms.to_clean[(uchar)*str];
+      if (c) *res++ = c;
+    }
+    *res = '\0';
+    
     /**  check word  **/
     i = j = z = 0;
     while ((c = word[i]) != '\0') {
@@ -363,7 +386,7 @@ namespace aspeller {
                 s++;
               }
               if (k > k0)
-                strcpy (&word[0]+i+k0, &word[0]+i+k);
+                strmove (&word[0]+i+k0, &word[0]+i+k);
 
               /**  new "actual letter"  **/
               c = word[i];
@@ -387,8 +410,7 @@ namespace aspeller {
                   target[j] = c;
                   j++;
                 }
-                // FIXME: This may overlap
-                strcpy (&word[0], &word[0]+i+1);
+                strmove (&word[0], &word[0]+i+1);
                 i = 0;
                 z0 = 1;
               }
@@ -421,7 +443,7 @@ namespace aspeller {
     return (j);
 
   }  /**  end of function "phonet"  **/
-}
+} }
 
 #if 0
 
