@@ -24,10 +24,10 @@ namespace aspell { namespace sp {
       memcpy(rest,  lang->sl_rest_, 256);
       return no_err;
     }
+    
     String soundslike_chars() const {
-      int i;
       bool chars_set[256] = {0};
-      for ( i = 0; i != 256; ++i) 
+      for (int i = 0; i != 256; ++i) 
       {
         char c = first[i];
         if (c) chars_set[static_cast<unsigned char>(c)] = true;
@@ -35,7 +35,7 @@ namespace aspell { namespace sp {
         if (c) chars_set[static_cast<unsigned char>(c)] = true;
       }
       String     chars_list;
-      for ( i = 0; i != 256; ++i) 
+      for (int i = 0; i != 256; ++i) 
       {
         if (chars_set[i]) 
           chars_list += static_cast<char>(i);
