@@ -1,5 +1,5 @@
 // This file is part of The New Aspell
-// Copyright (C) 2000-2001 by Kevin Atkinson under the GNU LGPL
+// Copyright (C) 2000-2001,2011 by Kevin Atkinson under the GNU LGPL
 // license version 2.0 or 2.1.  You should have received a copy of the
 // LGPL license along with this library if you did not you can find it
 // at http://www.gnu.org/.
@@ -83,20 +83,28 @@ namespace aspell { namespace sp {
     String cor1, cor2;
     String buf;
     bool correct = false;
-    if (pos = cor.find(' '), pos == String::npos) {
+    pos = cor.find(' '); 
+    if (pos == String::npos) {
       cor1 = cor;
       correct = check_affix(cor, w1, 0);
     } else {
       cor1 = (String)cor.substr(0,pos);
-      cor2 = (String)cor.substr(pos+1);
+      ++pos;
+      while (pos < cor.size() && cor[pos] == ' ') ++pos;
+      cor2 = (String)cor.substr(pos);
       correct = check_affix(cor1, w1, 0) && check_affix(cor2, w2, 0);
     }
     if (correct) {
       String cor_orignal_casing(cor1);
       if (!cor2.empty()) {
-        cor_orignal_casing += cor[pos];
+        cor_orignal_casing += cor[pos-1];
         cor_orignal_casing += cor2;
       }
+      // Don't try to add the empty string, causes all kinds of
+      // problems.  Can happen if the original replacement nothing but
+      // whitespace.
+      if (cor_orignal_casing.empty()) 
+        return no_err;
       if (first_word == 0 || cor != first_word) {
         lang().to_lower(buf, mis.str());
         repl_->add_repl(buf, cor_orignal_casing);
@@ -129,7 +137,7 @@ namespace aspell { namespace sp {
   {
     w0.clear(); // FIXME: is this necessary?
     const char * x = w;
-    while (*x != '\0' && (x-w.str()) < static_cast<int>(ignore_count)) ++x;
+    while (*x != '\0' && (x-w) < static_cast<int>(ignore_count)) ++x;
     if (*x == '\0') {w0.word = w; return true;}
     WS::const_iterator i   = check_ws.begin();
     WS::const_iterator end = check_ws.end();
@@ -464,8 +472,8 @@ namespace aspell { namespace sp {
     assert (config_ == 0);
     config_.reset(c);
 
-    ignore_repl = config_->retrieve_bool("ignore-repl").data;
-    ignore_count = config_->retrieve_int("ignore").data;
+    ignore_repl = config_->retrieve_bool("ignore-repl");
+    ignore_count = config_->retrieve_int("ignore");
 
     DictList to_add;
     RET_ON_ERR(add_data_set(config_->retrieve("master-path"), *config_, &to_add, this));
@@ -537,12 +545,12 @@ namespace aspell { namespace sp {
     unconditional_run_together_ = config_->retrieve_bool("run-together");
     run_together = unconditional_run_together_;
     
-    run_together_limit_  = config_->retrieve_int("run-together-limit").data;
+    run_together_limit_  = config_->retrieve_int("run-together-limit");
     if (run_together_limit_ > 8) {
       config_->replace("run-together-limit", "8");
       run_together_limit_ = 8;
     }
-    run_together_min_    = config_->retrieve_int("run-together-min").data;
+    run_together_min_    = config_->retrieve_int("run-together-min");
 
     config_->add_notifier(new ConfigNotifier(this));
 
