@@ -15,13 +15,32 @@
 
 #include <math.h>
 
-#include "settings.h"
 #include "vector_hash.hpp"
 #include "primes.hpp"
 
 namespace aspell { namespace sp {
 
+  template <class Parms>
+  VectorHashTable<Parms>::FindIterator
+  ::FindIterator(const HashTable * ht, const key_type & k)
+    : vector(&ht->vector())
+    , parms(&ht->parms())
+    , key(k)
+    , i(ht->hash1(k))
+    , hash2(ht->hash2(k))
+  {
+    if (!parms->is_nonexistent((*vector)[i])
+	&& !parms->equal(parms->key((*vector)[i]), key))
+      adv();
+  }
 
+  template <class Parms>
+  void VectorHashTable<Parms>::FindIterator::adv() {
+    do {
+      i = (i + hash2) % vector->size();
+    } while (!parms->is_nonexistent((*vector)[i])
+	     && !parms->equal(parms->key((*vector)[i]), key));
+  }
 
   template<class Parms>
   void VectorHashTable<Parms>::nonexistent_vector() {
@@ -32,7 +51,7 @@ namespace aspell { namespace sp {
   }
   
   template<class Parms>
-  std::pair<TYPENAME VectorHashTable<Parms>::iterator, bool> 
+  std::pair<typename VectorHashTable<Parms>::iterator, bool>
   VectorHashTable<Parms>::insert(const value_type & d) 
   {
     MutableFindIterator j(this, parms_.key(d));
@@ -56,7 +75,26 @@ namespace aspell { namespace sp {
     return !ConstFindIterator(this,key).at_end();
   }
 
+  template<class Parms>
+  typename VectorHashTable<Parms>::iterator 
+  VectorHashTable<Parms>::find(const key_type & key) 
+  {
+    MutableFindIterator i(this, key);
+    if (!i.at_end()) 
+      return iterator(vector_.begin() + i.i, this);
+    else
+      return end();
+  }
 
+  template<class Parms>
+  typename VectorHashTable<Parms>::const_iterator 
+  VectorHashTable<Parms>::find(const key_type & key) const {
+    ConstFindIterator i(this, key);
+    if (!i.at_end()) 
+      return const_iterator(vector_.begin() + i.i, this);
+    else
+      return end();
+  }
 
 #if 0 // it currently doesn't work needs fixing
 
@@ -134,8 +172,8 @@ namespace aspell { namespace sp {
   }
 
   template<class Parms>
-  void VectorHashTable<Parms>::resize(size_type size_) {
-    VectorHashTable temp(size_,parms_);
+  void VectorHashTable<Parms>::resize(size_type i) {
+    VectorHashTable temp(i,parms_);
     iterator e = end();
     for (iterator i = begin(); i != e; ++i)
       temp.insert(*i);
