@@ -1,3 +1,9 @@
+// This file is part of The New Aspell
+// Copyright (C) 2000,2011 by Kevin Atkinson under the GNU LGPL
+// license version 2.0 or 2.1.  You should have received a copy of the
+// LGPL license along with this library if you did not you can find it
+// at http://www.gnu.org/.
+
 #include <time.h>
 
 #include "file_util.hpp"
@@ -25,7 +31,7 @@ typedef const char * Str;
 typedef unsigned char byte;
 
 struct Hash {
-  InsensitiveHash f;
+  InsensitiveHash<> f;
   Hash(const LangImpl * l) : f(l) {}
   size_t operator() (Str s) const {
     return f(s);
@@ -84,8 +90,48 @@ struct LookupParams
   Equal equal;
   Str key (const HashValue & v) const { return v->key(); }
 };
- 
 
+void write_n_escape(FStream & o, const char * str) {
+  while (*str != '\0') {
+    if (*str == '\n') o << "\\n";
+    else if (*str == '\r') o << "\\r";
+    else if (*str == '\\') o << "\\\\";
+    else o << *str;
+    ++str;
+  }
+}
+
+static inline char f_getc(FStream & in) {
+  int c = in.get();
+  return c == EOF ? '\0' : (char)c;
+}
+  
+bool getline_n_unescape(FStream & in, String & str, char delem) {
+  str.clear();
+  char c = f_getc(in);
+  if (!c) return false;
+  while (c && c != delem) {
+    if (c == '\\') {
+      c = f_getc(in);
+      if (c == 'n') str.append('\n');
+      else if (c == 'r') str.append('\r');
+      else if (c == '\\') str.append('\\');
+      else {str.append('\\'); continue;}
+    } else {
+      str.append(c);
+    }
+    c = f_getc(in);
+  }
+  return true;
+}
+
+bool getline_n_unescape(FStream & in, DataPair & d, String & buf)
+{
+  if (!getline_n_unescape(in, buf, '\n')) return false;
+  d.value.str  = buf.mstr();
+  d.value.size = buf.size();
+  return true;
+}
 
 class WritableBase : public Dictionary {
 protected:
@@ -603,7 +649,7 @@ PosibErr<void> WritableDict::merge(FStream & in,
     set_file_encoding("", *config);
   
   ConvP conv(iconv);
-  while (getline(in, dp, buf)) {
+  while (getline_n_unescape(in, dp, buf)) {
     if (ver == 10)
       split(dp);
     else
@@ -622,8 +668,8 @@ inline void WritableBase::save_words(FStream& out, InputIterator i, InputIterato
 {
   ConvP conv(oconv);
   for (;i != e; ++i) {
-    const char *w = (*i)->word_;
-    out.printf("%s\n", conv(w));
+    write_n_escape(out, conv((*i)->key()));
+    out << '\n';
   }
 }
 
@@ -939,7 +985,10 @@ PosibErr<void> WritableReplDict::save (FStream & out, ParmString file_name)
     WordVec & v = repl->correct;
     for (WordVec::iterator j = v.begin(); j != v.end(); ++j)
     {
-      out.printf("%s %s\n", conv1(repl->key()), conv2((*j)->key()));
+      write_n_escape(out, conv1(repl->key()));
+      out << ' ';
+      write_n_escape(out, conv2((*j)->key()));
+      out << '\n';
     }
   }
   return no_err;
@@ -951,7 +1000,6 @@ PosibErr<void> WritableReplDict::merge(FStream & in,
 {
   typedef PosibErr<void> Ret;
   unsigned int version;
-  String word, mis, sound, repl;
   unsigned int num_words, num_repls;
 
   String buf;
@@ -993,16 +1041,21 @@ PosibErr<void> WritableReplDict::merge(FStream & in,
 
     ConvP conv1(iconv);
     ConvP conv2(iconv);
-    do {
-      in.getline(mis, ' ');
-      if (!in) break;
-      in.getline(repl, '\n');
-      if (!in) make_err(bad_file_format, file_name);
+    for (;;) {
+      bool res = getline_n_unescape(in, buf, '\n');
+      if (!res) break;
+      char * mis = buf.mstr();
+      char * repl = strchr(mis, ' ');
+      if (!repl) continue; // bad line, ignore
+      *repl = '\0'; // split string
+      ++repl;
+      if (!repl[0]) continue; // empty repl, ignore
       WritableReplDict::add_repl(conv1(mis), conv2(repl));
-    } while (true);
-
+    }
+    
   } else {
-
+    
+    String mis, sound, repl;
     unsigned int h,i,j;
     for (h=0; h != num_soundslikes; ++h) {
       in >> sound >> num_words;
